@@ -12,6 +12,7 @@
 #include <stddef.h>
 #include <stdint.h>
 
+#include <array>
 #include <cmath>
 #include <tuple>
 
@@ -1420,9 +1421,11 @@ TEST_F(VideoRendererAlgorithmTest, VariablePlaybackRateCadence) {
   TickGenerator frame_tg(base::TimeTicks(), NTSC(30));
   TickGenerator display_tg(tick_clock_->NowTicks(), 60);
 
-  const double kPlaybackRates[] = {1.0, 2, 0.215, 0.5, 1.0, 3.15};
-  const bool kTestRateHasCadence[std::size(kPlaybackRates)] = {
-      true, true, true, true, true, false};
+  const auto kPlaybackRates =
+      std::to_array<double>({1.0, 2, 0.215, 0.5, 1.0, 3.15});
+  const std::array<bool, std::size(kPlaybackRates)> kTestRateHasCadence = {
+      true, true, true, true, true, false,
+  };
 
   for (size_t i = 0; i < std::size(kPlaybackRates); ++i) {
     const double playback_rate = kPlaybackRates[i];
@@ -1447,10 +1450,11 @@ TEST_F(VideoRendererAlgorithmTest, UglyTimestampsHaveCadence) {
   time_source_.StartTicking();
 
   // 59.94fps, timestamp deltas from https://youtu.be/byoLvAo9qjs
-  const int kBadTimestampsMs[] = {
+  const auto kBadTimestampsMs = std::to_array<int>({
       17, 16, 17, 17, 16, 17, 17, 16, 17, 17, 17, 16, 17, 17, 16, 17, 17, 16,
       17, 17, 16, 17, 17, 16, 17, 17, 16, 17, 17, 17, 16, 17, 17, 16, 17, 17,
-      16, 17, 17, 16, 17, 17, 16, 17, 17, 16, 17, 17, 16, 17, 17, 17};
+      16, 17, 17, 16, 17, 17, 16, 17, 17, 16, 17, 17, 16, 17, 17, 17,
+  });
 
   // Run through ~1.6 seconds worth of frames.
   bool cadence_detected = false;
@@ -1482,9 +1486,26 @@ TEST_F(VideoRendererAlgorithmTest, VariableFrameRateNoCadence) {
   TickGenerator display_tg(tick_clock_->NowTicks(), 60);
   time_source_.StartTicking();
 
-  const int kBadTimestampsMs[] = {200,  200,  200,  200,  200,  1000,
-                                  1000, 1000, 1000, 200,  200,  200,
-                                  200,  200,  1000, 1000, 1000, 1000};
+  const auto kBadTimestampsMs = std::to_array<int>({
+      200,
+      200,
+      200,
+      200,
+      200,
+      1000,
+      1000,
+      1000,
+      1000,
+      200,
+      200,
+      200,
+      200,
+      200,
+      1000,
+      1000,
+      1000,
+      1000,
+  });
 
   // Run throught ~10 seconds worth of frames.
   bool cadence_detected = false;
